.. _quickstart:

Tutorial: Quickstart
====================

Use the following line as your first import ...

.. code-block:: python

    from textblob_de import TextBlobDE as TextBlob


... and follow the `quickstart guide <http://textblob.readthedocs.org/en/dev/quickstart.html>`_ 
in the documentation of the main package (using German examples and starting with 
"Let's create our first **TextBlob**").